@@ -17,17 +17,16 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.2.15"
-from atoms import *
-from expressions.variables import Variable, Semidef
-from expressions.constants import Parameter, CallbackParam, Constant
-from problems.problem import Problem
-from problems.objective import Maximize, Minimize
-import interface.numpy_wrapper
-from error import SolverError
-from settings import (CVXOPT, ECOS, SCS,
+__version__ = "0.2.16"
+from cvxpy.atoms import *
+from cvxpy.expressions.variables import Variable, Semidef, Bool, Int
+from cvxpy.expressions.constants import Parameter, CallbackParam, Constant
+from cvxpy.problems.problem import Problem
+from cvxpy.problems.objective import Maximize, Minimize
+from cvxpy.error import SolverError
+from cvxpy.settings import (CVXOPT, ECOS, ECOS_BB, SCS,
 OPTIMAL, UNBOUNDED, INFEASIBLE, SOLVER_ERROR,
 OPTIMAL_INACCURATE, UNBOUNDED_INACCURATE, INFEASIBLE_INACCURATE)
 
 # Legacy names.
-from expressions.variables.semidefinite import Semidef as semidefinite
+from cvxpy.expressions.variables.semidef_var import Semidef as semidefinite
