@@ -17,6 +17,7 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+
 from .. import settings as s
 from .. import utilities as u
 from .. import interface as intf
@@ -24,6 +25,10 @@ from ..expressions.constants import Constant, CallbackParam
 from ..expressions.variables import Variable
 from ..expressions.expression import Expression
 import abc
+import sys
+if sys.version_info >= (3, 0):
+    from functools import reduce
+
 
 class Atom(Expression):
     """ Abstract base class for atoms. """
@@ -125,7 +130,7 @@ class Atom(Expression):
         return None
 
     @abc.abstractmethod
-    def graph_implementation(arg_objs, size, data=None):
+    def graph_implementation(self, arg_objs, size, data=None):
         """Reduces the atom to an affine expression and list of constraints.
 
         Parameters
