@@ -17,9 +17,11 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from eq_constraint import EqConstraint
-from exponential import ExpCone
-from leq_constraint import LeqConstraint
-from second_order import SOC
-from semi_definite import SDP
-from soc_elemwise import SOC_Elemwise
+from cvxpy.constraints.bool_constr import BoolConstr
+from cvxpy.constraints.eq_constraint import EqConstraint
+from cvxpy.constraints.exponential import ExpCone
+from cvxpy.constraints.int_constr import IntConstr
+from cvxpy.constraints.leq_constraint import LeqConstraint
+from cvxpy.constraints.second_order import SOC
+from cvxpy.constraints.semi_definite import SDP
+from cvxpy.constraints.soc_elemwise import SOC_Elemwise
