@@ -17,6 +17,6 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from constant import Constant
-from callback_param import CallbackParam
-from parameter import Parameter
+from .constant import Constant
+from .callback_param import CallbackParam
+from .parameter import Parameter
