@@ -22,7 +22,7 @@ import cvxpy.utilities as u
 import cvxpy.settings as s
 from cvxpy.utilities import performance_utils as pu
 from cvxpy.constraints import EqConstraint, LeqConstraint
-import types
+from cvxpy.expressions import types
 import abc
 import numpy as np
 
@@ -196,7 +196,9 @@ class Expression(u.Canonical):
     def __pow__(self, power):
         """The power operator.
         """
-        if power == 2:
+        if not np.isscalar(power):
+            raise TypeError("Power must be a numeric scalar.")
+        elif power == 2:
             return types.square()(self)
         elif power == 0.5:
             return types.sqrt()(self)
@@ -244,16 +246,19 @@ class Expression(u.Canonical):
         if not self.is_constant() and \
            not other.is_constant():
             raise TypeError("Cannot multiply two non-constants.")
-        # The constant term must always be on the left.
+        # Multiplying by a constant on the right is handled differently
+        # from multiplying by a constant on the left.
         elif not self.is_constant():
-            # If other is a scalar, simply move it left.
-            if other.is_scalar():
-                return types.mul_expr()(other, self)
-            else:
-                return (other.T * self.T).T
+            return types.rmul_expr()(self, other)
         else:
             return types.mul_expr()(self, other)
 
+    @_cast_other
+    def __truediv__(self, other):
+        """One expression divided by another.
+        """
+        return self.__div__(other)
+
     @_cast_other
     def __div__(self, other):
         """One expression divided by another.
@@ -270,6 +275,12 @@ class Expression(u.Canonical):
         """
         return other / self
 
+    @_cast_other
+    def __rtruediv__(self, other):
+        """Called for Number / Expression.
+        """
+        return other / self
+
     @_cast_other
     def __rmul__(self, other):
         """Called for Number * Expression.
@@ -281,6 +292,10 @@ class Expression(u.Canonical):
         """
         return types.neg_expr()(self)
 
+    #needed for python3:
+    def __hash__(self):
+        return id(self)
+
     # Comparison operators.
     @_cast_other
     def __eq__(self, other):
