@@ -37,6 +37,9 @@ PROMOTE = "promote"
 # Multiplying an expression by a constant.
 # Data: LinOp evaluating to the left hand multiple.
 MUL = "mul"
+# Multiplying an expression by a constant on the right.
+# Data: LinOp evaluating to the right hand multiple.
+RMUL = "rmul"
 # Multiplying an expression elementwise by a constant.
 # Data: LinOp evaluating to the left hand multiple.
 MUL_ELEM = "mul_elem"
@@ -68,6 +71,9 @@ DIAG_VEC = "diag_vec"
 # Converts the diagonal of a matrix to a vector.
 # Data: None
 DIAG_MAT = "diag_mat"
+# Vectorized upper triangular portion of a matrix.
+# Data: None
+UPPER_TRI = "upper_tri"
 # The 1D discrete convolution of two vectors.
 # Data: LinOp evaluating to the left hand term.
 CONV = "conv"
