@@ -18,8 +18,9 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from cvxpy.problems.solvers.ecos_intf import ECOS
+from cvxpy.problems.solvers.ecos_bb_intf import ECOS_BB
 from cvxpy.problems.solvers.cvxopt_intf import CVXOPT
 from cvxpy.problems.solvers.scs_intf import SCS
 
-solver_intf = [ECOS(), CVXOPT(), SCS()]
+solver_intf = [ECOS(), ECOS_BB(), CVXOPT(), SCS()]
 SOLVERS = {solver.name():solver for solver in solver_intf}
