@@ -76,6 +76,15 @@ class TestAtoms(unittest.TestCase):
         self.assertEquals(norm2(atom).curvature, u.Curvature.CONVEX_KEY)
         self.assertEquals(norm2(-atom).curvature, u.Curvature.CONVEX_KEY)
 
+    # Test the geo_mean class.
+    def test_geo_mean(self):
+        exp = self.x+self.y
+        atom = geo_mean(exp, self.x)
+        # self.assertEquals(atom.name(), "norm2(x + y)")
+        self.assertEquals(atom.size, (2,1))
+        self.assertEquals(atom.curvature, u.Curvature.CONCAVE_KEY)
+        self.assertEquals(atom.sign, u.Sign.POSITIVE_KEY)
+
     def test_quad_over_lin(self):
         # Test quad_over_lin DCP.
         atom = quad_over_lin(square(self.x), self.a)
@@ -97,13 +106,15 @@ class TestAtoms(unittest.TestCase):
         """
         with self.assertRaises(Exception) as cm:
             max_elemwise(1)
-        self.assertEqual(str(cm.exception),
-            "__init__() takes at least 3 arguments (2 given)")
+        self.assertTrue(str(cm.exception) in (
+            "__init__() takes at least 3 arguments (2 given)",
+            "__init__() missing 1 required positional argument: 'arg2'"))
 
         with self.assertRaises(Exception) as cm:
             min_elemwise(1)
-        self.assertEqual(str(cm.exception),
-            "__init__() takes at least 3 arguments (2 given)")
+        self.assertTrue(str(cm.exception) in (
+            "__init__() takes at least 3 arguments (2 given)",
+            "__init__() missing 1 required positional argument: 'arg2'"))
 
     def test_matrix_frac(self):
         """Test for the matrix_frac atom.
@@ -330,3 +341,46 @@ class TestAtoms(unittest.TestCase):
             trace(self.C)
         self.assertEqual(str(cm.exception),
             "Argument to trace must be a square matrix.")
+
+    def test_log1p(self):
+        """Test the log1p atom.
+        """
+        expr = log1p(1)
+        self.assertEquals(expr.sign, u.Sign.POSITIVE_KEY)
+        self.assertEquals(expr.curvature, u.Curvature.CONSTANT_KEY)
+        self.assertEquals(expr.size, (1, 1))
+        expr = log1p(-0.5)
+        self.assertEquals(expr.sign, u.Sign.NEGATIVE_KEY)
+
+    def test_upper_tri(self):
+        with self.assertRaises(Exception) as cm:
+            upper_tri(self.C)
+        self.assertEqual(str(cm.exception),
+            "Argument to upper_tri must be a square matrix.")
+
+    def test_huber(self):
+        # Valid.
+        huber(self.x, 1)
+
+        with self.assertRaises(Exception) as cm:
+            huber(self.x, -1)
+        self.assertEqual(str(cm.exception),
+            "M must be a non-negative scalar constant.")
+
+        with self.assertRaises(Exception) as cm:
+            huber(self.x, [1,1])
+        self.assertEqual(str(cm.exception),
+            "M must be a non-negative scalar constant.")
+
+        # M parameter.
+        M = Parameter(sign="positive")
+        # Valid.
+        huber(self.x, M)
+        M.value = 1
+        self.assertAlmostEquals(huber(2, M).value, 3)
+        # Invalid.
+        M = Parameter(sign="negative")
+        with self.assertRaises(Exception) as cm:
+            huber(self.x, M)
+        self.assertEqual(str(cm.exception),
+            "M must be a non-negative scalar constant.")
