@@ -54,8 +54,8 @@ atoms = [
             Constant([[math.e, 1],[math.e**2, 1.0/math.e]])),
         (huber, (2, 2), [ [[0.5, -1.5],[4, 0]] ],
             Constant([[0.25, 2],[7, 0]])),
-        (lambda x: huber(x, 2.5), (2, 2), [ [[0.5, -1.5],[4, 0]] ],
-            Constant([[0.25, 2.25],[13.75, 0]])),
+        # (lambda x: huber(x, 2.5), (2, 2), [ [[0.5, -1.5],[4, 0]] ],
+        #     Constant([[0.25, 2.25],[13.75, 0]])),
         (inv_pos, (2, 2), [ [[1,2],[3,4]] ],
             Constant([[1,1.0/2],[1.0/3,1.0/4]])),
         (lambda x: (x + Constant(0))**-1, (2, 2), [ [[1,2],[3,4]] ],
@@ -119,6 +119,7 @@ atoms = [
         # #(square_over_lin(2,4), 1),
         (lambda x: norm(x, 2), (1, 1), [ [[2,0],[0,1]] ], Constant([2])),
         (lambda x: norm(x, 2), (1, 1), [ [[3,4,5],[6,7,8],[9,10,11]] ], Constant([22.368559552680377])),
+        (lambda x: scalene(x, 2, 3), (2, 2), [ [[-5,2],[-3,1]] ], Constant([[15,4],[9,2]])),
         (square, (2, 2), [ [[-5,2],[-3,1]] ], Constant([[25,4],[9,1]])),
         (lambda x: (x + Constant(0))**2, (2, 2), [ [[-5,2],[-3,1]] ], Constant([[25,4],[9,1]])),
         (sum_squares, (1, 1), [ [[-1, 2],[3, -4]] ], Constant([30])),
@@ -130,6 +131,7 @@ atoms = [
         (tv, (1, 1), [ [[-5,2],[-3,1]], [[6,5],[-4,3]], [[8,0],[15,9]] ],
             Constant([LA.norm([7, -1, -8, 2, -10, 7])])),
         (tv, (1, 1), [ [[3,4,5],[6,7,8],[9,10,11]] ], Constant([4*math.sqrt(10)])),
+        (upper_tri, (3, 1), [ [[3,4,5],[6,7,8],[9,10,11]] ], Constant([6, 9, 10])),
     ], Minimize),
     ([
         (entr, (2, 2), [ [[1, math.e],[math.e**2, 1.0/math.e]] ],
@@ -141,10 +143,12 @@ atoms = [
                   [5, 2, 5, 2],
                   [2, 4, 2, 4]] ], Constant([7.7424])),
         (geo_mean, (1, 1), [4,1], Constant([2])),
-        (geo_mean, (1,1), [2,2], Constant([2])),
+        # (geo_mean, (1, 1), [0,7], Constant([0])),
+        (geo_mean, (3, 2), [ [[2,63,3], [1,1,2]], [[8,7,3],[10,4,2]] ], Constant([[4,21,3],[math.sqrt(10),2,2]])),
         (lambda_min, (1, 1), [ [[2,0],[0,1]] ], Constant([1])),
         (lambda_min, (1, 1), [ [[5,7],[7,-3]] ], Constant([-7.06225775])),
         (log, (2, 2), [ [[1, math.e],[math.e**2, 1.0/math.e]] ], Constant([[0, 1],[2, -1]])),
+        (log1p, (2, 2), [ [[0, math.e-1],[math.e**2-1, 1.0/math.e-1]] ], Constant([[0, 1],[2, -1]])),
         (min_elemwise, (2, 1), [ [-5,2],[-3,1],0,[1,2] ], Constant([-5,0])),
         (min_elemwise, (2, 2), [ [[-5,2],[-3,-1]],0,[[5,4],[-1,2]] ], Constant([[-5,0],[-3,-1]])),
         (min_entries, (1, 1), [ [[-5,2],[-3,1]] ], Constant([-5])),
@@ -168,21 +172,21 @@ def check_solver(prob, solver_name):
     try:
         solver.validate_solver(constraints)
         return True
-    except Exception, e:
+    except Exception as e:
         return False
 
 # Tests numeric version of atoms.
 def run_atom(atom, problem, obj_val, solver):
     assert problem.is_dcp()
-    print problem.objective
-    print problem.constraints
+    print(problem.objective)
+    print(problem.constraints)
     if check_solver(problem, solver):
-        print "solver", solver
+        print("solver", solver)
         tolerance = SOLVER_TO_TOL[solver]
-        result = problem.solve(solver=solver)
+        result = problem.solve(solver=solver, verbose=True)
         if problem.status is OPTIMAL:
-            print result
-            print obj_val
+            print(result)
+            print(obj_val)
             assert( -tolerance <= result - obj_val <= tolerance )
         else:
             assert (atom, solver) in KNOWN_SOLVER_ERRORS
@@ -190,8 +194,8 @@ def run_atom(atom, problem, obj_val, solver):
 def test_atom():
     for atom_list, objective_type in atoms:
         for atom, size, args, obj_val in atom_list:
-            for row in xrange(size[0]):
-                for col in xrange(size[1]):
+            for row in range(size[0]):
+                for col in range(size[1]):
                     for solver in [ECOS, SCS, CVXOPT]:
                         # Atoms with Constant arguments.
                         yield (run_atom,
