@@ -22,12 +22,13 @@ from cvxpy.expressions.expression import *
 from cvxpy.expressions.variables import Variable
 from cvxpy.expressions.constants import Constant
 from cvxpy.expressions.constants import Parameter
+from cvxpy import Problem, Minimize
 import cvxpy.utilities as u
 import cvxpy.interface.matrix_utilities as intf
 import cvxpy.settings as s
 from collections import deque
 import unittest
-from base_test import BaseTest
+from cvxpy.tests.base_test import BaseTest
 from cvxopt import matrix
 import numpy as np
 import warnings
@@ -349,7 +350,7 @@ class TestExpressions(BaseTest):
         # Scalar constants on the right should be moved left
         # instead of taking the transpose.
         expr = self.C*2
-        self.assertEqual(expr.args[0].value, 2)
+        self.assertEqual(expr.args[1].value, 2)
 
     # Test the DivExpresion class.
     def test_div_expression(self):
@@ -364,7 +365,7 @@ class TestExpressions(BaseTest):
 
         with self.assertRaises(Exception) as cm:
             (self.x/[2,2,3])
-        print cm.exception
+        print(cm.exception)
         self.assertEqual(str(cm.exception), "Can only divide by a scalar constant.")
 
         # Constant expressions.
@@ -545,6 +546,17 @@ class TestExpressions(BaseTest):
         self.assertEquals(exp.size, (2, 1))
         self.assertEquals(exp.curvature, u.Curvature.CONSTANT_KEY)
 
+        c = Constant([1,2,3,4])
+        exp = c[::-1]
+        self.assertItemsAlmostEqual(exp.value, [4, 3, 2, 1])
+        self.assertEquals(exp.size, (4, 1))
+        self.assertEquals(exp.curvature, u.Curvature.CONSTANT_KEY)
+
+        x = Variable(4)
+        Problem(Minimize(0), [x[::-1] == c]).solve()
+        self.assertItemsAlmostEqual(x.value, [4, 3, 2, 1])
+        self.assertEquals(x.size, (4, 1))
+
     def test_logical_indices(self):
         """Test indexing with logical arrays.
         """
@@ -560,4 +572,7 @@ class TestExpressions(BaseTest):
         with self.assertRaises(Exception) as cm:
             (self.x**3)
         self.assertEqual(str(cm.exception), "Invalid power: 3.")
+        with self.assertRaises(Exception) as cm:
+            (self.x**self.x)
+        self.assertEqual(str(cm.exception), "Power must be a numeric scalar.")
 
