@@ -25,7 +25,10 @@ import cvxpy.interface as intf
 import numpy as np
 import scipy.sparse as sp
 import unittest
-from base_test import BaseTest
+from cvxpy.tests.base_test import BaseTest
+import sys
+PY2 = sys.version_info < (3, 0)
+
 
 class test_lin_ops(BaseTest):
     """ Unit tests for the lin_ops module. """
@@ -96,7 +99,11 @@ class test_lin_ops(BaseTest):
         # Expanding dict.
         add_expr = sum_expr([x, y, A])
         vars_ = get_expr_vars(add_expr)
-        self.assertItemsEqual(vars_, [(x.data, size), (y.data, size)])
+        ref = [(x.data, size), (y.data, size)]
+        if PY2:
+            self.assertItemsEqual(vars_, ref)
+        else:
+            self.assertCountEqual(vars_, ref)
 
     def test_neg_expr(self):
         """Test negating an expression.
@@ -120,7 +127,11 @@ class test_lin_ops(BaseTest):
         constr = create_eq(lh_expr, rh_expr)
         self.assertEqual(constr.size, size)
         vars_ = get_expr_vars(constr.expr)
-        self.assertItemsEqual(vars_, [(x.data, size), (y.data, size)])
+        ref = [(x.data, size), (y.data, size)]
+        if PY2:
+            self.assertItemsEqual(vars_, ref)
+        else:
+            self.assertCountEqual(vars_, ref)
 
     def test_leq_constr(self):
         """Test creating a less than or equal constraint.
@@ -134,7 +145,11 @@ class test_lin_ops(BaseTest):
         constr = create_leq(lh_expr, rh_expr)
         self.assertEqual(constr.size, size)
         vars_ = get_expr_vars(constr.expr)
-        self.assertItemsEqual(vars_, [(x.data, size), (y.data, size)])
+        ref = [(x.data, size), (y.data, size)]
+        if PY2:
+            self.assertItemsEqual(vars_, ref)
+        else:
+            self.assertCountEqual(vars_, ref)
 
     def test_get_coefficients(self):
         """Test the get_coefficients function.
