@@ -20,25 +20,29 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 import cvxpy.settings as s
 from cvxpy.atoms import *
 from cvxpy.expressions.constants import Constant, Parameter
-from cvxpy.expressions.variables import Variable, Semidef
+from cvxpy.expressions.variables import Variable, Semidef, Bool
 from cvxpy.problems.objective import *
 from cvxpy.problems.problem import Problem
 from cvxpy.problems.solvers.utilities import SOLVERS
 from cvxpy.problems.problem_data.sym_data import SymData
 import cvxpy.interface as intf
 import cvxpy.lin_ops.lin_utils as lu
-from base_test import BaseTest
+from cvxpy.tests.base_test import BaseTest
 from cvxopt import matrix
 from numpy import linalg as LA
 import numpy
 import unittest
 import math
 import sys
-from cStringIO import StringIO
 # Solvers.
 import scs
 import cvxopt.solvers
 import ecos
+PY2 = sys.version_info < (3, 0)
+if sys.version_info < (3, 0):
+    from cStringIO import StringIO
+else:
+    from io import StringIO
 
 class TestProblem(BaseTest):
     """ Unit tests for the expression/expression module. """
@@ -75,7 +79,11 @@ class TestProblem(BaseTest):
         """
         p = Problem(Minimize(self.a), [self.a <= self.x, self.b <= self.A + 2])
         vars_ = p.variables()
-        self.assertItemsEqual(vars_, [self.a, self.x, self.b, self.A])
+        ref = [self.a, self.x, self.b, self.A]
+        if PY2:
+            self.assertItemsEqual(vars_, ref)
+        else:
+            self.assertCountEqual(vars_, ref)
 
     def test_parameters(self):
         """Test the parameters method.
@@ -85,7 +93,11 @@ class TestProblem(BaseTest):
         p3 = Parameter(4, 4, sign="positive")
         p = Problem(Minimize(p1), [self.a + p1 <= p2, self.b <= p3 + p3 + 2])
         params = p.parameters()
-        self.assertItemsEqual(params, [p1, p2, p3])
+        ref = [p1, p2, p3]
+        if PY2:
+            self.assertItemsEqual(params, ref)
+        else:
+            self.assertCountEqual(params, ref)
 
     def test_get_problem_data(self):
         """Test get_problem_data method.
@@ -157,11 +169,13 @@ class TestProblem(BaseTest):
 
         # ####
         for verbose in [True, False]:
-            for solver in [s.ECOS, s.CVXOPT, s.SCS]:
-                sys.stdout = StringIO()     # capture output
+            for solver in s.SOLVERS:
+                sys.stdout = StringIO() # capture output
                 p = Problem(Minimize(self.a + self.x[0]), [self.a >= 2, self.x >= 2])
+                if solver in s.MIP_CAPABLE:
+                    p.constraints.append(Bool() == 0)
                 p.solve(verbose=verbose, solver=solver)
-                if solver != s.ECOS:
+                if solver in s.EXP_CAPABLE:
                     p = Problem(Minimize(self.a), [log(self.a) >= 2])
                     p.solve(verbose=verbose, solver=solver)
                 out = sys.stdout.getvalue() # release output
@@ -174,6 +188,7 @@ class TestProblem(BaseTest):
         for output in outputs[True]:
             assert len(output) > 0
         for output in outputs[False]:
+            print(output)
             assert len(output) == 0
 
     # Test registering other solve methods.
@@ -218,7 +233,7 @@ class TestProblem(BaseTest):
             sym_data = SymData(objective, constraints, SOLVERS[s.ECOS])
             # Sort by offset.
             vars_ = sorted(sym_data.var_offsets.items(),
-                key=lambda (var_id, offset): offset)
+                key=lambda key_val: key_val[1])
             vars_ = [var_id for (var_id, offset) in vars_]
             vars_lists.append(vars_)
             ineqs_lists.append(sym_data.constr_map[s.LEQ])
@@ -253,7 +268,7 @@ class TestProblem(BaseTest):
         obj = sum_entries(X + X)
         p = Problem(Minimize(obj))
         result = p.solve(method="test")
-        self.assertEqual(result, (1, 1))
+        self.assertEqual(result, (0, 1))
 
         # Duplicates from non-linear constraints.
         exp = norm(self.x, 2)
@@ -370,7 +385,7 @@ class TestProblem(BaseTest):
         result = p.solve()
         self.assertAlmostEqual(result, 26, places=3)
         obj = c.T*self.x.value + self.a.value
-        self.assertAlmostEqual(obj[0], result)
+        self.assertAlmostEqual(obj[0,0], result)
         self.assertItemsAlmostEqual(self.x.value, [8,8], places=3)
         self.assertItemsAlmostEqual(self.z.value, [2,2], places=3)
 
@@ -475,8 +490,8 @@ class TestProblem(BaseTest):
         p = Problem(Minimize(normInf(self.x - self.z) + 5),
             [self.x >= [2,3], self.z <= [-1,-4]])
         result = p.solve()
-        self.assertAlmostEqual(result, 12)
-        self.assertAlmostEqual(list(self.x.value)[1] - list(self.z.value)[1], 7)
+        self.assertAlmostEqual(float(result), 12)
+        self.assertAlmostEqual(float(list(self.x.value)[1] - list(self.z.value)[1]), 7)
 
     # Test problems with norm1
     def test_norm1(self):
@@ -501,8 +516,8 @@ class TestProblem(BaseTest):
         p = Problem(Minimize(norm1(self.x - self.z) + 5),
             [self.x >= [2,3], self.z <= [-1,-4]])
         result = p.solve()
-        self.assertAlmostEqual(result, 15)
-        self.assertAlmostEqual(list(self.x.value)[1] - list(self.z.value)[1], 7)
+        self.assertAlmostEqual(float(result), 15)
+        self.assertAlmostEqual(float(list(self.x.value)[1] - list(self.z.value)[1]), 7)
 
     # Test problems with norm2
     def test_norm2(self):
@@ -1122,3 +1137,9 @@ class TestProblem(BaseTest):
         x0.value = 1
         prob.solve()
         self.assertAlmostEqual(prob.value, 1)
+
+    def test_geo_mean(self):
+        cost = sum_entries(geo_mean(self.x, 1))
+        prob = Problem(Maximize(cost), [self.x == 1])
+        prob.solve()
+        self.assertAlmostEqual(prob.value, 2)
